﻿
namespace RIAServicesWithPoco.Web.Models
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.ComponentModel.DataAnnotations;
    using System.Data.Objects.DataClasses;
    using System.Linq;
    using System.ServiceModel.DomainServices.Hosting;
    using System.ServiceModel.DomainServices.Server;


    // The MetadataTypeAttribute identifies ArtistMetadata as the class
    // that carries additional metadata for the Artist class.
    [MetadataTypeAttribute(typeof(Artist.ArtistMetadata))]
    public partial class Artist
    {

        // This class allows you to attach custom attributes to properties
        // of the Artist class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class ArtistMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private ArtistMetadata()
            {
            }

            public EntityCollection<Album> Albums { get; set; }

            public int ArtistId { get; set; }

            public string Name { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies CustomerMetadata as the class
    // that carries additional metadata for the Customer class.
    [MetadataTypeAttribute(typeof(Customer.CustomerMetadata))]
    public partial class Customer
    {

        // This class allows you to attach custom attributes to properties
        // of the Customer class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class CustomerMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private CustomerMetadata()
            {
            }

            public string Address { get; set; }

            public string City { get; set; }

            public string Company { get; set; }

            public string Country { get; set; }

            public int CustomerId { get; set; }

            public string Email { get; set; }

            public Employee Employee { get; set; }

            public string Fax { get; set; }

            public string FirstName { get; set; }

            public EntityCollection<Invoice> Invoices { get; set; }

            public string LastName { get; set; }

            public string Phone { get; set; }

            public string PostalCode { get; set; }

            public string State { get; set; }

            public Nullable<int> SupportRepId { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies EmployeeMetadata as the class
    // that carries additional metadata for the Employee class.
    [MetadataTypeAttribute(typeof(Employee.EmployeeMetadata))]
    public partial class Employee
    {

        // This class allows you to attach custom attributes to properties
        // of the Employee class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class EmployeeMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private EmployeeMetadata()
            {
            }

            public string Address { get; set; }

            public Nullable<DateTime> BirthDate { get; set; }

            public string City { get; set; }

            public string Country { get; set; }

            public EntityCollection<Customer> Customers { get; set; }

            public string Email { get; set; }

            public EntityCollection<Employee> Employee1 { get; set; }

            public Employee Employee2 { get; set; }

            public int EmployeeId { get; set; }

            public string Fax { get; set; }

            public string FirstName { get; set; }

            public Nullable<DateTime> HireDate { get; set; }

            public string LastName { get; set; }

            public string Phone { get; set; }

            public string PostalCode { get; set; }

            public Nullable<int> ReportsTo { get; set; }

            public string State { get; set; }

            public string Title { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies GenreMetadata as the class
    // that carries additional metadata for the Genre class.
    [MetadataTypeAttribute(typeof(Genre.GenreMetadata))]
    public partial class Genre
    {

        // This class allows you to attach custom attributes to properties
        // of the Genre class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class GenreMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private GenreMetadata()
            {
            }

            public int GenreId { get; set; }

            public string Name { get; set; }

            public EntityCollection<Track> Tracks { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies InvoiceMetadata as the class
    // that carries additional metadata for the Invoice class.
    [MetadataTypeAttribute(typeof(Invoice.InvoiceMetadata))]
    public partial class Invoice
    {

        // This class allows you to attach custom attributes to properties
        // of the Invoice class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class InvoiceMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private InvoiceMetadata()
            {
            }

            public string BillingAddress { get; set; }

            public string BillingCity { get; set; }

            public string BillingCountry { get; set; }

            public string BillingPostalCode { get; set; }

            public string BillingState { get; set; }

            public Customer Customer { get; set; }

            public int CustomerId { get; set; }

            public DateTime InvoiceDate { get; set; }

            public int InvoiceId { get; set; }

            public EntityCollection<InvoiceLine> InvoiceLines { get; set; }

            public decimal Total { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies InvoiceLineMetadata as the class
    // that carries additional metadata for the InvoiceLine class.
    [MetadataTypeAttribute(typeof(InvoiceLine.InvoiceLineMetadata))]
    public partial class InvoiceLine
    {

        // This class allows you to attach custom attributes to properties
        // of the InvoiceLine class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class InvoiceLineMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private InvoiceLineMetadata()
            {
            }

            public Invoice Invoice { get; set; }

            public int InvoiceId { get; set; }

            public int InvoiceLineId { get; set; }

            public int Quantity { get; set; }

            public Track Track { get; set; }

            public int TrackId { get; set; }

            public decimal UnitPrice { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies MediaTypeMetadata as the class
    // that carries additional metadata for the MediaType class.
    [MetadataTypeAttribute(typeof(MediaType.MediaTypeMetadata))]
    public partial class MediaType
    {

        // This class allows you to attach custom attributes to properties
        // of the MediaType class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class MediaTypeMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private MediaTypeMetadata()
            {
            }

            public int MediaTypeId { get; set; }

            public string Name { get; set; }

            public EntityCollection<Track> Tracks { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies PlaylistMetadata as the class
    // that carries additional metadata for the Playlist class.
    [MetadataTypeAttribute(typeof(Playlist.PlaylistMetadata))]
    public partial class Playlist
    {

        // This class allows you to attach custom attributes to properties
        // of the Playlist class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class PlaylistMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private PlaylistMetadata()
            {
            }

            public string Name { get; set; }

            public int PlaylistId { get; set; }

            public EntityCollection<Track> Tracks { get; set; }
        }
    }

    // The MetadataTypeAttribute identifies TrackMetadata as the class
    // that carries additional metadata for the Track class.
    [MetadataTypeAttribute(typeof(Track.TrackMetadata))]
    public partial class Track
    {

        // This class allows you to attach custom attributes to properties
        // of the Track class.
        //
        // For example, the following marks the Xyz property as a
        // required property and specifies the format for valid values:
        //    [Required]
        //    [RegularExpression("[A-Z][A-Za-z0-9]*")]
        //    [StringLength(32)]
        //    public string Xyz { get; set; }
        internal sealed class TrackMetadata
        {

            // Metadata classes are not meant to be instantiated.
            private TrackMetadata()
            {
            }

            public Album Album { get; set; }

            public Nullable<int> AlbumId { get; set; }

            public Nullable<int> Bytes { get; set; }

            public string Composer { get; set; }

            public Genre Genre { get; set; }

            public Nullable<int> GenreId { get; set; }

            public EntityCollection<InvoiceLine> InvoiceLines { get; set; }

            public MediaType MediaType { get; set; }

            public int MediaTypeId { get; set; }

            public int Milliseconds { get; set; }

            public string Name { get; set; }

            public EntityCollection<Playlist> Playlists { get; set; }

            public int TrackId { get; set; }

            public decimal UnitPrice { get; set; }
        }
    }
}
