﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;
using RIAServicesWithPoco.Web.Services;
using System.Linq.Expressions;
using System.Windows.Navigation;

namespace RIAServicesWithPoco.ViewModels
{
    public class ViewModelBase : DependencyObject, INotifyPropertyChanged
    {
        #region Constructors
        protected ViewModelBase()
        {
            _currentContext = new ChinookDomainContext();
        }
        #endregion

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        protected virtual void OnPropertyChanged<TProperty>(Expression<Func<TProperty>> property)
        {
            var lambda = (LambdaExpression)property;

            MemberExpression memberExpression;
            if (lambda.Body is UnaryExpression)
            {
                var unaryExpression = (UnaryExpression)lambda.Body;
                memberExpression = (MemberExpression)unaryExpression.Operand;
            }
            else memberExpression = (MemberExpression)lambda.Body;

            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(memberExpression.Member.Name));
            }
        }

        #endregion

        #region Domain Context
        private ChinookDomainContext _currentContext;
        public ChinookDomainContext CurrentContext
        {
            get { return _currentContext; }
            set { _currentContext = value; }
        }
        #endregion

        #region Events
        public event EventHandler<NavigationEventArgs> Navigate;
        protected void OnNavigate(NavigationEventArgs e)
        {
            if (Navigate != null)
            {
                Navigate(this, e);
            }
        }
        #endregion

    }
}
